@@ -108,11 +108,9 @@ def run(ctx: click.Context, data_job_directory: str, arguments: str) -> None:
     """
     Entry point of the CLI run. It start a run (execution) of a data job.
     """
-    click.echo(
-        f"Versatile Data Kit (VDK){os.linesep}{version.get_version_info()}",
-        err=True,
+    log.info(
+        f"Versatile Data Kit (VDK){os.linesep}{version.get_version_info()}{os.linesep + '-' * 80}"
     )
-    click.echo("-" * 80, err=True)
     context: CoreContext = cast(CoreContext, ctx.obj)
     run_impl = CliRunImpl()
     run_impl.run_job(context, pathlib.Path(data_job_directory), arguments)
